==> modx-2.1.4-pl-ja.zip: modx-2.1.4-pl-ja/core/lexicon/en/context.inc.php <==
<?php
/**
 * Context English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['context'] = 'Context';
$_lang['context_add'] = 'Add Context';
$_lang['context_create'] = 'Create Context';
$_lang['context_data'] = 'Context Data';
$_lang['context_duplicate'] = 'Duplicate Context';
$_lang['context_err_ae'] = 'A Context with that name already exists.';
$_lang['context_err_create'] = 'An error occurred while creating the Context.';
$_lang['context_err_duplicate'] = 'An error occurred while trying to duplicate the Context.';
$_lang['context_err_load_data'] = 'Error loading context data.';
$_lang['context_err_nf'] = 'Context not found!';
$_lang['context_err_nfs'] = 'Context not found with key: [[+key]]';
$_lang['context_err_ns'] = 'Context not specified.';
$_lang['context_err_ns_key'] = 'Please specify a valid key for the Context.';
$_lang['context_err_remove'] = 'An error occurred while removing the Context.';
$_lang['context_err_save'] = 'An error occurred while saving the Context.';
$_lang['context_id'] = 'Ctx ID';
$_lang['context_key'] = 'Context Key';
$_lang['context_management_message'] = 'Manage site Contexts.';
$_lang['context_refresh'] = 'Refresh Context';
$_lang['context_remove'] = 'Remove Context';
$_lang['context_remove_confirm'] = 'Are you sure you want to remove this Context? This is permanent and irreversible.';
$_lang['context_settings'] = 'Context Settings';
$_lang['context_settings_desc'] = 'Here you can set settings specific to this Context. Context settings will override any System Settings with the same key.';
$_lang['context_update'] = 'Update Context';
$_lang['context_with_key_not_found'] = 'Context with key %s not found!';
$_lang['contexts'] = 'Contexts';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/context.inc.php <==
<?php
/**
 * Context English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['context'] = 'Context';
$_lang['context_add'] = 'Add Context';
$_lang['context_create'] = 'Create Context';
$_lang['context_data'] = 'Context Data';
$_lang['context_duplicate'] = 'Duplicate Context';
$_lang['context_err_ae'] = 'A Context with that name already exists.';
$_lang['context_err_create'] = 'An error occurred while creating the Context.';
$_lang['context_err_duplicate'] = 'An error occurred while trying to duplicate the Context.';
$_lang['context_err_load_data'] = 'Error loading context data.';
$_lang['context_err_nf'] = 'Context not found!';
$_lang['context_err_nfs'] = 'Context not found with key: [[+key]]';
$_lang['context_err_ns'] = 'Context not specified.';
$_lang['context_err_ns_key'] = 'Please specify a valid key for the Context.';
$_lang['context_err_remove'] = 'An error occurred while removing the Context.';
$_lang['context_err_save'] = 'An error occurred while saving the Context.';
$_lang['context_id'] = 'Ctx ID';
$_lang['context_key'] = 'Context Key';
$_lang['context_management_message'] = 'Manage site Contexts.';
$_lang['context_refresh'] = 'Refresh Context';
$_lang['context_remove'] = 'Delete Context';
$_lang['context_remove_confirm'] = 'Are you sure you want to remove this Context? This is permanent and irreversible.';
$_lang['context_settings'] = 'Context Settings';
$_lang['context_settings_desc'] = 'Here you can set settings specific to this Context. Context settings will override any System Settings with the same key.';
$_lang['context_update'] = 'Update Context';
$_lang['context_with_key_not_found'] = 'Context with key %s not found!';
$_lang['contexts'] = 'Contexts';
